@@ -23,5 +23,8 @@ SOFTWARE.
 """
 
 from .async_session import (
-    Waifu,
+    WaifuAsync,
+)
+from .sync_session import (
+    WaifuSync,
 )
\ No newline at end of file
