@@ -22,4 +22,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-API_URL = "https://api.waifu.pics"
\ No newline at end of file
+API_URL = "https://api.waifu.pics"
+VALID_SFW_REQUESTS = [
+    'waifu', 'neko', 'shinobu', 'megumin', 'bully', 'cuddle', 
+    'cry', 'hug', 'awoo', 'kiss', 'lick', 'pat', 'smug', 'bonk', 
+    'yeet', 'blush', 'smile', 'wave', 'highfive', 'handhold', 
+    'nom', 'bite', 'glomp', 'slap', 'kill', 'kick', 'happy', 
+    'wink', 'poke', 'dance', 'cringe'
+]
+VALID_NSFW_REQUESTS = [
+    'waifu', 'neko', 'trap', 'blowjob'
+]
\ No newline at end of file
